/* WIDE AREA INFORMATION SERVER SOFTWARE:
   No guarantees or restrictions.  See the readme file for the full standard
   disclaimer.

   This is part of the shell user-interface for the WAIS software.  Do with it
   as you please.

   jonathan@Think.COM
*/

/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */


/*
 * $Log: qdisplay.h,v $
 * Revision 1.1.1.1  1996/06/04 20:38:46  julia
 * autoconf baseline
 *
 * Revision 1.1.1.1  1996/04/30 18:22:46  dmitriy
 * Version 2.1 -- autoconf baseline
 *
 * Revision 1.1.1.2  1996/04/23  19:47:33  dmitriy
 * autoconf baseline
 *
 * Revision 2.0.1.1  1995/09/15 09:57:05  pfeifer
 * patch7: Fixed CNIDR copyright line.
 *
 * Revision 2.0  1995/09/08  08:07:04  pfeifer
 * Metaconfig baseline
 *
 * Revision 1.2  1994/08/05  07:26:24  pfeifer
 * Release beta 04
 *
 * Revision 1.1  1993/02/16  15:10:18  freewais
 * Initial revision
 *
 * Revision 1.4  92/04/28  15:29:47  jonathan
 * More prototypes.
 * 
 * Revision 1.3  92/03/23  16:09:38  jonathan
 * Added MakeSaveRequester.
 * 
 * Revision 1.2  92/03/17  14:13:03  jonathan
 * *** empty log message ***
 * 
*/

#ifndef _H_QDISPLAY
#define _H_QDISPLAY

void SetqIcon (Widget parent);
void SettIcon (Widget parent);
Widget MakeQuestionPane (Widget parent,XQuestion question);
Widget MakeTextPopup (Widget parent, Textbuff t, char *name);
QuestionWindow MakeQuestionForm (XQuestion question);
Widget MakeSourcePopup (Widget parent);
Widget MakePrefPopup (Widget parent);
ScrollList MakeSourceFrame (Widget parent);
ScrollList MakeTypeFrame (Widget parent);
void MakeWaisCursors (void);
#endif

